# Summary

[Introduction](./README.md)

# User Guide

- [Getting started](./getting-started.md)
- [A simple example](./simple.md)

# Configuration

- [Website](./website.md)
- [Page](./page.md)
- [Environment](./env.md)

# Usage

- [Crawl](./crawl.md)
- [Scrape](./scrape.md)
- [Cron Job](./cron-job.md)
- [Storing Data](./storing-data.md)

# Benchmarks

- [Compare](./benchmarks.md)
